summaryrefslogtreecommitdiffstats
path: root/src/filterdialog.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit89c017c3d5126cabd96acce26f538b37b48c085f (patch)
tree115673043b52ffe2e5f8b01ebcd7b886e0a1318b /src/filterdialog.h
parent0254ebaa5e056092461fd585b6851d15faa43035 (diff)
downloadtellico-89c017c3d5126cabd96acce26f538b37b48c085f.tar.gz
tellico-89c017c3d5126cabd96acce26f538b37b48c085f.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/tellico@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/filterdialog.h')
-rw-r--r--src/filterdialog.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/filterdialog.h b/src/filterdialog.h
index 99823d8..26509ba 100644
--- a/src/filterdialog.h
+++ b/src/filterdialog.h
@@ -54,7 +54,7 @@ public:
* Constructor. You give a @ref FilterRule as parameter, which will
* be used to initialize the widget.
*/
- FilterRuleWidget(FilterRule* rule, TQWidget* tqparent, const char* name=0);
+ FilterRuleWidget(FilterRule* rule, TQWidget* parent, const char* name=0);
/**
* Set the rule. The rule is accepted regardless of the return
@@ -102,7 +102,7 @@ Q_OBJECT
TQ_OBJECT
public:
- FilterRuleWidgetLister(TQWidget* tqparent, const char* name=0);
+ FilterRuleWidgetLister(TQWidget* parent, const char* name=0);
const TQPtrList<TQWidget>& widgetList() const;
void setFilter(Filter::Ptr filter);
@@ -116,7 +116,7 @@ signals:
protected:
virtual void clearWidget(TQWidget* widget);
- virtual TQWidget* createWidget(TQWidget* tqparent);
+ virtual TQWidget* createWidget(TQWidget* parent);
};
/**
@@ -135,10 +135,10 @@ public:
/**
* The constructor sets up the dialog.
*
* @param tqparent A pointer to the tqparent widget
* @param name The widget name
*/
- FilterDialog(Mode mode, TQWidget* tqparent, const char* name=0);
+ FilterDialog(Mode mode, TQWidget* parent, const char* name=0);
FilterPtr currentFilter();
void setFilter(FilterPtr filter);
@@ -135,10 +135,10 @@ public:
* The constructor sets up the dialog.
*
- * @param tqparent A pointer to the tqparent widget
+ * @param parent A pointer to the parent widget
* @param name The widget name
*/